Improve this Doc

# $location

Here are the list of errors in the $location namespace.

Name | Description
--- | ---
badpath | Invalid Path
ipthprfx | Invalid or Missing Path Prefix
isrcharg | Wrong $location.search() argument type
nobase | $location in HTML5 mode requires a <base> tag to be present!
nostate | History API state support is available only in HTML5 mode and only in browsers supporting HTML5 History API